<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE Profile SYSTEM "profile.dtd">

<!--
 ==================================================================
   This file contains sample code.  IBM PROVIDES THIS CODE ON AN
   'AS IS' BASIS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANT ABILITY OR FITNESS FOR A PARTICULAR PURPOSE.

   (C) Copyright IBM Corporation 2000

 ==================================================================
  This cashier profile defines how Payment Manager KitCash orders are
  created using the SampleCheckout application and a KitCash wallet.
 ================================================================== -->

<Profile useWallet="true" enableTrace="false">

  <CollectPayment>

    <!-- ==================================================================
      The BuyPageInformation element contains the cassette's protocol data part 
      of an HTML form that buyers will use to create orders using this profile.
      The SampleCheckout application requires that the BuyPageInformation
      element contains HTML that can be imbedded within <FORM> and <TABLE>
      elements as follows:

        <FORM NAME="cassetteform" METHOD="POST" ACTION="/webapp/PaymentManager/SampleCheckout">
          <TABLE BORDER="0" WIDTH="100%" CELLSPACING="1" CELLPADDING="2">

            .... <BuyPageInformation> contents go here...

          </TABLE>
        </FORM>

      The "reference" attribute names a Java ResourceBundle that can be used
      to localize the contents of the buy page.  The SampleCheckout application
      will substitute any text found in curly braces ({}) with localized text
      from the appropriate resource bundle.  SampleCheckout uses the browser-
      specified locale to identify which localized ResourceBundle to use.  

      For example, if the reference is SampleCheckoutXXX and the user has set
      the browser's locale to fr_FR, SampleCheckout will search for substitutions 
      of text found inside curly braces with matching text from the 
      SampleCheckoutXXX_fr_FR.properties file.  If a match cannot be found, 
      the SampleCheckoutXXX_fr.properties and SampleCheckout.properties files
      will be searched in sequence.
     ================================================================== -->

    <BuyPageInformation reference="SampleCheckoutKitCash"><![CDATA[
      <TR>
        <TD COLSPAN="4">
          {KITCASHWALLETMESSAGE}
        </TD>
      </TR>
    ]]></BuyPageInformation>  


    <!-- ==================================================================
      The following sections contain the parameters required by Payment 
      Manager and the cassette to create the order.  

      The SampleCheckout application will pass the following
      environment variables to the cashier.  These variables can be used
      in the profile by enclosing the variable name in curly braces ({}).

           Variable Name          Content
           ============================================================
           merchantnumber         the merchant number as entered on the form
           ordernumber            the order number as entered on the form
           currency               the ISO 4217 currency selected on the form (3 digit code)
           currencyAlpha          the currency in ISO 4217 (3 letter code)
           amount                 the amount as entered on the form
           amountLowestCurrUnits  the amount value converted to the
                                  currency's lowest units.  E.g. in US
                                  dollars, 10.00 dollars converts to 
                                  1000 cents.
           paymentOption          the radio button value of the Payment option
                                  field on the form
           other variables as     the value entered on the form
           specified in the
           BuyPageInformation
           element

      If, after all substitutions have been made, the value of a parameter
      is an empty string, then the parameter will not be passed to 
      Payment Manager.
     ================================================================== -->



    <!-- ==================================================================
      Parameters required by Payment Manager for order creation
     ================================================================== -->
   
    <Parameter name="PAYMENTTYPE"><CharacterText>KitCash</CharacterText></Parameter>
    <Parameter name="MERCHANTNUMBER"><CharacterText>{merchantnumber}</CharacterText></Parameter>
    <Parameter name="ORDERNUMBER"><CharacterText>{ordernumber}</CharacterText></Parameter>
    <Parameter name="AMOUNT"><CharacterText>{amountLowestCurrUnits}</CharacterText></Parameter>
    <Parameter name="CURRENCY"><CharacterText>{currency}</CharacterText></Parameter>

    <!-- Account number is required on ReceivePayment.  For this example
         we've hard coded the value to the Inspirations department account
         456.  There are several methods for obtaining parameter values.
         Refer to the Programmer's Guide and Reference for details. -->
    <Parameter name="$ACCOUNTNUMBER"><CharacterText>456</CharacterText></Parameter>
    
    <!-- The following URLs are referenced depending on the status of the purchase.
         These parameters are examples of a Cashier Extension.  -->
    <Parameter name="$SUCCESSURL"><ExtensionValue name="com.ibm.etill.kitcashcassette.test.wallet.KitCashCashierExtension"/></Parameter>
    <Parameter name="$CANCELURL"><ExtensionValue name="com.ibm.etill.kitcashcassette.test.wallet.KitCashCashierExtension"/></Parameter>
    <Parameter name="$FAILUREURL"><ExtensionValue name="com.ibm.etill.kitcashcassette.test.wallet.KitCashCashierExtension"/></Parameter>
    <Parameter name="$PORT"><CharacterText>9081</CharacterText></Parameter>    
    
    <!--  Indicates how automatic approval of the order should be attempted
          Supported values are: 
            0 - no automatic approval
            1 - synchronous automatic approval - Payment Manager attempts approval as
                part of order creation operation
            2 - asynchronous automatic approval - Payment Manager schedules an approval
                operations after order is created
          The default value is 0.
     -->
    <Parameter name="APPROVEFLAG"><CharacterText>1</CharacterText></Parameter>
    
    <!-- Indicates whether the deposit should be attempted automatically. 
         This flag is only valid if APPROVEFLAG is set to 1 or 2.
         Supported values are:
           0 - Funds should not be automatically deposited. 
           1 - Funds should be automatically deposited. 
         The default value is 0.
    -->
    <Parameter name="DEPOSITFLAG"><CharacterText>1</CharacterText></Parameter>
    
    <!-- The payment number which used be used when approving an order.
         Usually this will be 1.  This field is required if the APPROVEFLAG
         is set to 1 or 2. -->
    <Parameter name="PAYMENTNUMBER"><CharacterText>1</CharacterText></Parameter>
    

    <!-- The amount which should be used when approving an order.  Usually
         this will be the same as the order amount.  This field is required
         if the APPROVEFLAG is set to 1 or 2. -->
    <Parameter name="PAYMENTAMOUNT"><CharacterText>{amountLowestCurrUnits}</CharacterText></Parameter>

  </CollectPayment>

</Profile>
